#
# Copyright INRA-URGI 2009-2010
# 
# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software. You can use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
# 
# As a counterpart to the access to the source code and rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty and the software's author, the holder of the
# economic rights, and the successive licensors have only limited
# liability.
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading, using, modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean that it is complicated to manipulate, and that also
# therefore means that it is reserved for developers and experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and, more generally, to use and operate it in the
# same conditions as regards security.
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.
#
from commons.core.writer.TranscriptListWriter import TranscriptListWriter


class MapWriter(TranscriptListWriter):
    """
    A class that writes a transcript list into a file with GFF3 format
    @ivar fileName: name of the file 
    @type fileName: string
    @ivar handle: handle to the file
    @type handle: file handle
    """


    def __init__(self, fileName, verbosity = 0, title="S-MART"):
        """
        Constructor
        @param fileName: name of the file 
        @type fileName: string
        @param verbosity: verbosity
        @type verbosity: int
        """
        self.header = ""
        self.title    = title
        TranscriptListWriter.__init__(self, fileName, verbosity)
            

    @staticmethod
    def getFileFormats():
        """
        Get the format of the file
        """
        return ["map"]
        
        
    @staticmethod
    def getExtension():
        """
        Get the usual extension for the file
        """
        return "map"
        
        
    def setTitle(self, title):
        """
        Set the title of the transcripts
        @param title: the title of the transcripts
        @type    title: string
        """
        self.title = title


    def printTranscript(self, transcript):
        """
        Export the given transcript to map format
        @param transcript: transcript to be printed
        @type transcript: class L{Transcript<Transcript>}
        @return: a string
        """
        name = transcript.name
        if "nbOccurrences" in transcript.getTagNames() and transcript.getTagValue("nbOccurrences") != 1 and transcript.getTagValue("occurrences"):
            name = "%s-%d" % (name, transcript.getTagValue("occurrence"))
        sizes   = []
        starts  = []
        transcript.sortExonsIncreasing()
        for exon in transcript.getExons():
            sizes.append("%d" % (exon.getSize()))
            starts.append("%d" % (exon.getStart() - transcript.getStart()))
        return "%s\t%s\t%d\t%d\n" % (name, transcript.getChromosome(), transcript.getStart(), transcript.getEnd()+1)



